#!/usr/bin/python
# -*- coding: utf-8 -*-

"""
wix: a SAT frontend
Copyright (C) 2009  Jérôme Poisson (goffi@goffi.org)

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""



import wx
import pdb
from xml.dom import minidom
from logging import debug, info, error
from tools.jid  import JID


class Form(wx.Frame):
    def __init__(self, host, xml_data='', title="Form", type="Form"):
        super(Form, self).__init__(None, title=title)

        self.host = host

        self.modified = {}  # dict of modified data (i.e. what we have to save)
        self.ctl_list = {}  # usefull to access ctrl, key = (name, category)

        self.sizer = wx.BoxSizer(wx.VERTICAL)
        self.SetSizer(self.sizer)
        self.SetAutoLayout(True)
        
        #events
        self.Bind(wx.EVT_CLOSE, self.onClose, self)
        
        self.MakeModal()

        self.constructForm(xml_data)

        self.Show()

    def constructForm(self, xml_data):
        panel=wx.Panel(self)
        panel.sizer = wx.BoxSizer(wx.VERTICAL)

        cat_dom = minidom.parseString(xml_data.encode('utf-8'))
        
        for elem in cat_dom.documentElement.getElementsByTagName("elem"):
            name = elem.getAttribute("name")
            label = elem.getAttribute("label") if elem.hasAttribute('label') else name
            type = elem.getAttribute("type")
            value = elem.firstChild.wholeText if elem.firstChild else u''  #TODO: must check if the first child is really the text value
            sizer = wx.BoxSizer(wx.HORIZONTAL)
            if type=="text":
                ctrl = wx.StaticText(panel, -1, value)
            elif type=="string":
                label=wx.StaticText(panel, -1, label+": ")
                ctrl = wx.TextCtrl(panel, -1, value)
                sizer.Add(label)
            elif type=="password":
                label=wx.StaticText(panel, -1, label+": ")
                ctrl = wx.TextCtrl(panel, -1, value, style=wx.TE_PASSWORD)
                sizer.Add(label)
            else:
                error("FIXME FIXME FIXME: type [%s] is not implemented" % type)  #FIXME !
                raise NotImplementedError
            sizer.Add(ctrl, 1, flag=wx.EXPAND)
            #self.ctl_list[(name, category)] = ctrl
            panel.sizer.Add(sizer, flag=wx.EXPAND)

            if type=="string" or type=="password":
                panel.Bind(wx.EVT_TEXT, self.onTextChanged, ctrl)

        panel.SetSizer(panel.sizer)
        panel.SetAutoLayout(True)
        panel.sizer.Fit(self)
        self.sizer.Add(panel, 1, flag=wx.EXPAND)
        cat_dom.unlink()

    def onTextChanged(self, event):
        """Called when a formated is modified"""
        #self.modified[event.GetEventObject().form_id]=event.GetString()
        
        event.Skip()
        
    def onClose(self, event):
        """Close event: we have to send the form."""
        debug("close")

        self.MakeModal(False)
        event.Skip()

